# lqcv
This is my computer vision lib.

## TODO
- [X] areas module support multi areas.
- [ ] fix stream reader saving problem(thread).
- [ ] scripts

## Quick Start

<details open>
<summary>Installation</summary>

```shell
git clone https://github.com/Laughing-q/lqcv.git
cd lqcv
pip install -e .
```

</details>

# Reference
[https://github.com/open-mmlab/mmcv](https://github.com/open-mmlab/mmcv)
[https://github.com/ultralytics/yolov5](https://github.com/ultralytics/yolov5)
[https://github.com/facebookresearch/detectron2.git](https://github.com/facebookresearch/detectron2.git)
